@@ -1,11 +1,10 @@
 import copy
-
 import galois
 import networkx as nx
 import numpy as np
-from .MajoranaCSSCode import MajoranaCSSCode
-from .. import MajoranaCode
-from ...Physics import MajoranaOperator
+from extendedstim.Code.QuantumCode.MajoranaCSSCode import MajoranaCSSCode
+from extendedstim.Code.QuantumCode.MajoranaCode import MajoranaCode
+from extendedstim.Physics import MajoranaOperator
 
 
 # %%  USER：实现fermionic lattice surgery
